| Title: | Human Protein Atlas Data for Tissue-Adjusted Pathway Analysis of Cancer (TPAC) |
|---|---|
| Description: | Contains summary data on gene expression in normal human tissues from the Human Protein Atlas for use with the Tissue-Adjusted Pathway Analysis of cancer (TPAC) method. Frost, H. Robert (2023) "Tissue-adjusted pathway analysis of cancer (TPAC)" <doi:10.1101/2022.03.17.484779>. |
| Authors: | H. Robert Frost [aut, cre] |
| Maintainer: | H. Robert Frost <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-05-20 06:40:06 UTC |
| Source: | https://github.com/cran/TPACData |
A data.table with 1,088,694 rows and 4 columns (Gene, Tissue, FPKM, TissueSpecificity):
Gene: Ensembl gene ID
Tissue: Human tissue type
FPKM: Mean expression of that gene in units FPKM+1
TissueSpecificity: The fold-change in expression between mean expression in that tissue and mean in all 18 tissues.
hpa.datahpa.data
A data.table with 1,088,694 rows and 4 columns (Gene, Tissue, FPKM, TissueSpecificity)
Human Protein Atlas
Ulhen et al. (2017). A pathology atlas of the human cancer transcriptome. Science. doi: 10.1126/science.aan2507